@@ -25,40 +25,40 @@ def load_project_env():
             vars[next[0]] = next[1]
     do_print = False
     ret = ""
-    if f"ndt.profile.{current_branch}.azure" in vars:
-        enable_profile("azure", vars[f"ndt.profile.{current_branch}.azure"])
+    if "ndt.profile." + current_branch + ".azure" in vars:
+        enable_profile("azure", vars["ndt.profile." + current_branch + ".azure"])
     elif "ndt.profile.azure" in vars:
         enable_profile("azure", vars["ndt.profile.azure"])
-    if f"ndt.profile.{current_branch}.adfs" in vars:
-        enable_profile("adfs", vars[f"ndt.profile.{current_branch}.adfs"])
+    if "ndt.profile." + current_branch + ".adfs" in vars:
+        enable_profile("adfs", vars["ndt.profile." + current_branch + ".adfs"])
     elif "ndt.profile.adfs" in vars:
         enable_profile("adfs", vars["ndt.profile.adfs"])
-    if f"ndt.profile.{current_branch}.iam" in vars:
-        enable_profile("iam", vars[f"ndt.profile.{current_branch}.iam"])
+    if "ndt.profile." + current_branch + ".iam" in vars:
+        enable_profile("iam", vars["ndt.profile." + current_branch + ".iam"])
     elif "ndt.profile.iam" in vars:
         enable_profile("iam", vars["ndt.profile.iam"])
-    if f"ndt.profile.{current_branch}.ndt" in vars:
-        enable_profile("ndt", vars[f"ndt.profile.{current_branch}.ndt"])
+    if "ndt.profile.{current_branch}.ndt" in vars:
+        enable_profile("ndt", vars["ndt.profile." + current_branch + ".ndt"])
     elif "ndt.profile.ndt" in vars:
         enable_profile("ndt", vars["ndt.profile.ndt"])
-    if f"ndt.source.{current_branch}.env" in vars:
+    if "ndt.source." + current_branch + ".env" in vars:
         do_print = True
-        ret = ret + ". " + vars[f"ndt.source.{current_branch}.env"] + linesep
+        ret = ret + ". " + vars["ndt.source." + current_branch + ".env"] + linesep
     elif "ndt.source.env" in vars:
         do_print = True
         ret = ret + ". " + vars["ndt.source.env"] + linesep
-    if f"ndt.aws.{current_branch}.profile" in vars:
+    if "ndt.aws." + current_branch + ".profile" in vars:
         do_print = True
-        ret = ret + "export AWS_PROFILE=" + vars[f"ndt.aws.{current_branch}.profile"] + \
-            " AWS_DEFAULT_PROFILE=" + vars[f"ndt.aws.{current_branch}.profile"] + linesep
+        ret = ret + "export AWS_PROFILE=" + vars["ndt.aws." + current_branch + ".profile"] + \
+            " AWS_DEFAULT_PROFILE=" + vars["ndt.aws." + current_branch + ".profile"] + linesep
     elif "ndt.aws.profile" in vars:
         do_print = True
         ret = ret + "export AWS_PROFILE=" + vars["ndt.aws.profile"] + \
             " AWS_DEFAULT_PROFILE=" + vars["ndt.aws.profile"] + linesep
-    if f"ndt.aws.{current_branch}.region" in vars:
+    if "ndt.aws.{current_branch}.region" in vars:
         do_print = True
-        ret = ret + "export AWS_REGION=" + vars[f"ndt.aws.{current_branch}.region"] + \
-            " AWS_DEFAULT_REGION=" + vars[f"ndt.aws.{current_branch}.region"] + linesep
+        ret = ret + "export AWS_REGION=" + vars["ndt.aws." + current_branch + ".region"] + \
+            " AWS_DEFAULT_REGION=" + vars["ndt.aws. " + current_branch + ".region"] + linesep
     elif "ndt.aws.region" in vars:
         do_print = True
         ret = ret + "export AWS_REGION=" + vars["ndt.aws.region"] + \
